@@ -13,7 +13,7 @@ using namespace KSieveUi;
 ManageSieveTreeView::ManageSieveTreeView(QWidget *parent)
     : PimCommon::CustomTreeView(parent)
 {
-    setDefaultText(i18n("No IMAP server configured..."));
+    setDefaultText(i18n("No IMAP server configured…"));
     setRootIsDecorated(true);
     setAlternatingRowColors(true);
     setSelectionMode(QAbstractItemView::SingleSelection);
@@ -27,7 +27,7 @@ ManageSieveTreeView::~ManageSieveTreeView() = default;
 void ManageSieveTreeView::setNoImapFound(bool found)
 {
     if (mShowDefaultText != found) {
-        setDefaultText(i18n("No IMAP server configured..."));
+        setDefaultText(i18n("No IMAP server configured…"));
         mShowDefaultText = found;
         update();
     }
